<?php
/**
 * Copyright © 2016 Filoblu S.r.l. All rights reserved.
 */

namespace FiloBlu\Esb\Setup;

use Magento\Framework\Setup\ModuleContextInterface;
use Magento\Framework\Setup\SchemaSetupInterface;
use Magento\Framework\Setup\UpgradeSchemaInterface;

/**
 * Class UpgradeSchema
 * @package FiloBlu\Esb\Setup
 */
class UpgradeSchema implements UpgradeSchemaInterface
{

    /**
     * @param SchemaSetupInterface $setup
     * @param ModuleContextInterface $context
     */
    public function upgrade(SchemaSetupInterface $setup, ModuleContextInterface $context)
    {
        $setup->startSetup();

        if (version_compare($context->getVersion(), '1.0.1') < 0) {

            // Get module table
            $tableName = $setup->getTable('esb_schedule');
            $connection = $setup->getConnection();
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                // Declare data
                $connection->addColumn(
                    $tableName,
                    'object_repository_interface',
                    [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'default' => NULL,
                        'nullable' => true,
                        'comment' => 'Object Repository Interface',
                        'after' => 'object_class'
                    ]
                );
                $connection->modifyColumn(
                    $tableName,
                    'object_class',
                    [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'default' => NULL,
                        'comment' => 'Object Class',
                        'nullable' => true
                    ]
                );
            }
        }

        if (version_compare($context->getVersion(), '1.0.5') < 0) {
            $tableName = $setup->getTable('esb_schedule');
            $connection = $setup->getConnection();
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                // Declare data
                $connection->addColumn(
                    $tableName,
                    'object_after_method',
                    [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'default' => NULL,
                        'nullable' => true,
                        'comment' => 'Method to be executed after export',
                        'after' => 'event'
                    ]
                );
                $connection->addColumn(
                    $tableName,
                    'object_after_method_argument',
                    [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'default' => NULL,
                        'nullable' => true,
                        'comment' => 'Method to be executed after export (argument)',
                        'after' => 'object_after_method'
                    ]
                );
            }
        }
        
        if (version_compare($context->getVersion(), '1.0.19') < 0) {
            $tableName = $setup->getTable('esb_schedule');
            $connection = $setup->getConnection();
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                $connection->addColumn(
                    $tableName,
                    'priority',
                    [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_INTEGER,
                        'unsigned' => true,
                        'default' => 0,
                        'nullable' => false,
                        'comment' => 'Priority',
                        'after' => 'response'
                    ]
                );
            }
        }

        if (version_compare($context->getVersion(), '1.1.8') < 0) {
            $tableName = $setup->getTable('esb_schedule');
            $connection = $setup->getConnection();
            if ($setup->getConnection()->isTableExists($tableName) == true) {
                $connection->addColumn(
                    $tableName,
                    'sendmessage_class',
                    [
                        'type' => \Magento\Framework\DB\Ddl\Table::TYPE_TEXT,
                        'length' => 255,
                        'default' => '\FiloBlu\Esb\Cron\SendMessage',
                        'nullable' => true,
                        'comment' => 'SendMessage class',
                        'after' => 'event'
                    ]
                );
            }
        }
        
        $setup->endSetup();
    }
}